@@ -558,11 +558,14 @@ ctrGetQueryUrl <- function(
   # if no parameter specified,
   # check clipboard contents
   if (nchar(url) == 0L) {
-    url <- suppressWarnings(
+    url <- try(suppressWarnings(
       clipr::read_clip(
-        allow_non_interactive = TRUE)
-    )
-    if (is.null(url) || (length(url) != 1L) || (nchar(url) == 0L)) {
+        allow_non_interactive = TRUE)),
+      silent = TRUE)
+    if (inherits(url, "try-error")) url <- ""
+    if (is.null(url) || (length(url) != 1L) || (nchar(url) == 0L) ||
+        grepl("[^-a-zA-Z/:_.0-9%#+?=&]", url) ||
+        !grepl("^https://", url)) {
       stop("ctrGetQueryUrl(): no clinical trial register ",
            "search URL found in parameter 'url' or in clipboard.",
            call. = FALSE)
@@ -578,13 +581,21 @@ ctrGetQueryUrl <- function(
   }
   #
   # identify domain and register short name
-  if (register == "") {
-    register <- switch(
+  registerFromUrl <- switch(
       sub("^https://[w]{0,3}[.]?([a-zA-Z.]+)/.*", "\\1", url),
       "clinicaltrialsregister.eu" = "EUCTR",
       "clinicaltrials.gov" = "CTGOV",
       "isrctn.com" = "ISRCTN",
+      "beta.clinicaltrials.gov" = "BETACTGOV",
       "NONE")
+  #
+  # check parameters expectations
+  if (register != "" && registerFromUrl != "NONE" && register != registerFromUrl) {
+    stop("ctrGetQueryUrl(): 'url' and / or 'register' mismatch, url: '",
+         deparse(url), "', register: '", deparse(register), "'",
+         call. = FALSE)
+  } else {
+    if (registerFromUrl != "NONE") register <- registerFromUrl
   }
   #
   outdf <- function(qt, reg) {
@@ -621,11 +632,11 @@ ctrGetQueryUrl <- function(
   }
   #
   if (register == "CTGOV") {
-    # single trial page
-    queryterm <- sub(paste0(".*/ct2/show/(", regCtgov, ")([?][a-z]+.*|$)"),
+    #
+    queryterm <- sub(paste0(".*/ct2/show/[recodsult/]*(", regCtgov, ")([?][a-z]+.*|$)"),
                      "\\1", url)
-    # inform user
-    if (grepl("[?][a-z]+=\\w+", url, perl = TRUE) &
+    # single trial page
+    if (grepl("[?][a-z]+=\\w+", url, perl = TRUE) &&
         grepl(paste0("^", regCtgov, "$"), queryterm)) {
       message("* Note: 'url' shows a single trial (and is returned by the ",
               "function) but also had search parameters: If interested in ",
@@ -666,6 +677,15 @@ ctrGetQueryUrl <- function(
     return(outdf(queryterm, register))
   }
   #
+  if (register == "BETACTGOV") {
+    #
+    stop("The beta website of ClinicalTrials.gov is not supported, ",
+         "please use the classic website. Package 'ctrdata' is being ",
+         "prepared to use the forthcoming website's functionality.")
+    #
+    return(invisible(NULL))
+  }
+  #
   # default / NONE
   warning("ctrGetQueryUrl(): no clinical trial register ",
           "search URL found in parameter 'url' or in clipboard.",
@@ -1749,7 +1769,7 @@ dbGetFieldsIntoDf <- function(fields = "",
 #' `_id`, `identifier`, `name`, `value` (and `where`, with the
 #'  contents of `wherevalue` found at `wherename`).
 #'  Contents of `value` are strings unless all its elements
-#'  are numbers. The `ìdentifier` is generated by function
+#'  are numbers. The `identifier` is generated by function
 #'  \link{dfTrials2Long} to identify matching elements, e.g.
 #'  endpoint descriptions and measurements.
 #'
@@ -1996,7 +2016,7 @@ dfTrials2Long <- function(df) {
       # and by cell in column
       lapply(ci, function(c) {
         if (is.data.frame(c)) {
-          # decompose
+          # unlist is numbering repeat item names
           x <- unlist(flattenDf(c))
           if (!is.null(names(x))) tn <- paste0(tn, ".", names(x))
           if (is.null(x)) x <- NA
@@ -2013,9 +2033,21 @@ dfTrials2Long <- function(df) {
           tnn <- NULL
           # need to iterate since there may be repeats, e.g, 1, 2, 3.1, 3.2
           sapply(seq_len(length(c)), function(i) {
-            # decompose
+            # unlist is numbering repeat item names
             x <- unlist(flattenDf(c[i]))
-            if (!is.null(names(x))) tn <- paste0(tn, ".", i, ".", names(x))
+            if (!is.null(names(x))) {
+              # any first numeric identifier?
+              tst <- stringi::stri_extract_first_regex(names(x), "[0-9]+")
+              if (all(!is.na(tst))) {
+                # if yes bring into middle
+                tn <- paste0(
+                  tn, ".", tst, ".",
+                  stringi::stri_replace_first_regex(names(x), "[0-9]+", ""))
+              } else {
+                # if no add using i
+                tn <- paste0(tn, ".", i, ".", names(x))
+              }
+            }
             if (is.null(x)) x <- NA
             xx <<- c(xx, x)
             tnn <<- c(tnn, tn)
