@@ -25,9 +25,9 @@ tf <- function() {
   }, add = TRUE)
 
   # check server
-  httr::set_config(httr::timeout(seconds = 60))
+  httr::set_config(httr::timeout(60L))
   if (httr::status_code(
-    httr::GET("https://www.isrctn.com/editAdvancedSearch")) != 200L
+    httr::HEAD("https://www.isrctn.com/editAdvancedSearch")) != 200L
   ) return(exit_file("Reason: ISRCTN not working"))
 
   # do tests
